'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _enzyme = require('enzyme');

var _chaiEnzyme = require('chai-enzyme');

var _chaiEnzyme2 = _interopRequireDefault(_chaiEnzyme);

var _Field = require('../containers/Field');

var _Field2 = _interopRequireDefault(_Field);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_chai2.default.use((0, _chaiEnzyme2.default)());

describe('Field component', function () {
  it('renders `widget` element (if not specified - `input`)', function () {
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, null)).find('input')).to.exist;
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { widget: 'select' })).find('select')).to.exist;
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { widget: 'textarea' })).find('textarea')).to.exist;
  });

  it('renders `label` element', function () {
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { label: 'Hello, field!' })).find('label')).to.have.text('Hello, field!');
  });

  it('renders `errors` and `moreErrors`', function () {
    var errors = (0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { errors: ['No', 'one'] })).find('.errors li').map(function (i) {
      return i.text();
    });
    (0, _chai.expect)(errors).to.eql(['No', 'one']);

    var moreErrors = (0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { moreErrors: ['should', null, 'pass'] })).find('.errors li').map(function (i) {
      return i.text();
    });
    (0, _chai.expect)(moreErrors).to.eql(['should', 'pass']);

    var combined = (0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { errors: ['the', undefined], moreErrors: 'gates' })).find('.errors li').map(function (i) {
      return i.text();
    });
    (0, _chai.expect)(combined).to.eql(['the', 'gates']);
  });

  it('doesn`t render errors if `errOnDirty` is true, field is not dirty and has errors', function () {
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { errOnDirty: true, dirty: true, errors: ['No', 'one'] })).find('.errors')).to.exist;
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { errOnDirty: true, dirty: false, errors: ['No', 'one'] })).find('.errors')).to.not.exist;
  });

  it('injects all props to the `widget` element', function () {
    (0, _chai.expect)((0, _enzyme.shallow)(_react2.default.createElement(_Field2.default, { id: 'name', className: 'myName', value: 'john', label: 'User' })).find('input').props()).to.eql({
      id: 'name',
      className: 'myName',
      value: 'john',
      label: 'User',
      children: undefined
    });
  });
});